@@ -2,92 +2,17 @@ use strict;
 use warnings;
 
 package App::Cmd::Simple;
+BEGIN {
+  $App::Cmd::Simple::VERSION = '0.311';
+}
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command' }
 
-our $VERSION = '0.307';
+# ABSTRACT: a helper for building one-command App::Cmd applications
 
 use App::Cmd;
 use Sub::Install;
 
-=head1 NAME
-
-App::Cmd::Simple - a helper for building one-command App::Cmd applications
-
-=head1 SYNOPSIS
-
-in F<simplecmd>:
-
-  use YourApp::Cmd;
-  Your::Cmd->run;
-
-in F<YourApp/Cmd.pm>:
-
-  package YourApp::Cmd;
-  use base qw(App::Cmd::Simple);
-
-  sub opt_spec {
-    return (
-      [ "blortex|X",  "use the blortex algorithm" ],
-      [ "recheck|r",  "recheck all results"       ],
-    );
-  }
-
-  sub validate_args {
-    my ($self, $opt, $args) = @_;
-
-    # no args allowed but options!
-    $self->usage_error("No args allowed") if @$args;
-  }
-
-  sub execute {
-    my ($self, $opt, $args) = @_;
-
-    my $result = $opt->{blortex} ? blortex() : blort();
-
-    recheck($result) if $opt->{recheck};
-
-    print $result;
-  }
-
-and, finally, at the command line:
-
-  knight!rjbs$ simplecmd --recheck
-
-  All blorts successful.
-
-=head1 SUBCLASSING
-
-When writing a subclass of App::Cmd:Simple, there are only a few methods that
-you might want to implement.  They behave just like the same-named methods in
-App::Cmd.
-
-=head2 opt_spec
-
-This method should be overridden to provide option specifications.  (This is
-list of arguments passed to C<describe_options> from Getopt::Long::Descriptive,
-after the first.)
-
-If not overridden, it returns an empty list.
-
-=head2 validate_args
-
-  $cmd->validate_args(\%opt, \@args);
-
-This method is passed a hashref of command line options (as processed by
-Getopt::Long::Descriptive) and an arrayref of leftover arguments.  It may throw
-an exception (preferably by calling C<usage_error>) if they are invalid, or it
-may do nothing to allow processing to continue.
-
-=head2 execute
-
-  Your::App::Cmd::Simple->execute(\%opt, \@args);
-
-This method does whatever it is the command should do!  It is passed a hash
-reference of the parsed command-line options and an array reference of left
-over arguments.
-
-=cut
 
 # The idea here is that the user will someday replace "Simple" in his ISA with
 # "Command" and then write a standard App::Cmd package.  To make that possible,
@@ -165,6 +90,93 @@ sub usage_desc {
 
 sub _cmd_pkg { }
 
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::Cmd::Simple - a helper for building one-command App::Cmd applications
+
+=head1 VERSION
+
+version 0.311
+
+=head1 SYNOPSIS
+
+in F<simplecmd>:
+
+  use YourApp::Cmd;
+  Your::Cmd->run;
+
+in F<YourApp/Cmd.pm>:
+
+  package YourApp::Cmd;
+  use base qw(App::Cmd::Simple);
+
+  sub opt_spec {
+    return (
+      [ "blortex|X",  "use the blortex algorithm" ],
+      [ "recheck|r",  "recheck all results"       ],
+    );
+  }
+
+  sub validate_args {
+    my ($self, $opt, $args) = @_;
+
+    # no args allowed but options!
+    $self->usage_error("No args allowed") if @$args;
+  }
+
+  sub execute {
+    my ($self, $opt, $args) = @_;
+
+    my $result = $opt->{blortex} ? blortex() : blort();
+
+    recheck($result) if $opt->{recheck};
+
+    print $result;
+  }
+
+and, finally, at the command line:
+
+  knight!rjbs$ simplecmd --recheck
+
+  All blorts successful.
+
+=head1 SUBCLASSING
+
+When writing a subclass of App::Cmd:Simple, there are only a few methods that
+you might want to implement.  They behave just like the same-named methods in
+App::Cmd.
+
+=head2 opt_spec
+
+This method should be overridden to provide option specifications.  (This is
+list of arguments passed to C<describe_options> from Getopt::Long::Descriptive,
+after the first.)
+
+If not overridden, it returns an empty list.
+
+=head2 validate_args
+
+  $cmd->validate_args(\%opt, \@args);
+
+This method is passed a hashref of command line options (as processed by
+Getopt::Long::Descriptive) and an arrayref of leftover arguments.  It may throw
+an exception (preferably by calling C<usage_error>) if they are invalid, or it
+may do nothing to allow processing to continue.
+
+=head2 execute
+
+  Your::App::Cmd::Simple->execute(\%opt, \@args);
+
+This method does whatever it is the command should do!  It is passed a hash
+reference of the parsed command-line options and an array reference of left
+over arguments.
+
 =head1 WARNINGS
 
 B<This should be considered experimental!>  Although it is probably not going
@@ -184,13 +196,16 @@ That's how things work.  You can just do this:
 
   YourApp::Cmd->import->run;
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2007, (code (simply)).  All rights reserved;  App::Cmd and
-bundled code are free software, released under the same terms as perl itself.
+Ricardo Signes <rjbs@cpan.org>
 
-App::Cmd::Simple was originally written by Ricardo SIGNES in 2007.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
